import React, {  } from 'react';
import { Row, Col, Modal, Button, Table } from 'react-bootstrap'
import { Box } from '@mui/material';
import { Formik, Field, Form } from 'formik';
import * as Yup from 'yup';

import ToggleButton from '@mui/material/ToggleButton';
import ToggleButtonGroup from '@mui/material/ToggleButtonGroup';

import ViewListIcon from '@mui/icons-material/ViewList';
import ViewModuleIcon from '@mui/icons-material/ViewModule';

import RemoveRedEyeIcon from '@mui/icons-material/RemoveRedEye';
import EditIcon from '@mui/icons-material/Edit';
import HighlightOffIcon from '@mui/icons-material/HighlightOff';

import NotFound from '../Images/not_found.png';

const NewPlazaSchema = Yup.object().shape({
    nombre : Yup.string().required('El nombre es requerido').min(5).max(20),
    description : Yup.string().required('La description es requerida').min(5).max(20),
    salario : Yup.number().required('El salario es requerido')
})
    
let data = [{
    nombre : 'The standard Lorem Ipsum passage, used since the 1500s',
    description : '"Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."',
    salario :  'Q 10,000',
    id :  0,
}]

function* idMaker() {
    var index = 1;
    while(true)
        yield index++;
}

var ID = idMaker(); // "Generator { }"

for ( var _ of new Array(46) ){
    data.push({
        ...data[0],
        id : ID.next().value,
        d : _ 
    })
}
function ListMode() {

    let actions = [
        <Button className="ver_producto">Ver</Button>,
        <Button className="editar_producto">Editar</Button>,
        <Button className="eliminar_producto">Eliminar</Button>,
    ]

    return(
        <Col md="12">
            <div className="body-table">
                <Table responsive borderless id="tablaproductos">
                    <thead>
                        <tr >
                            <th className="text-center">Nombre de la plaza</th>
                            <th className="text-center">Descripción</th>
                            <th className="text-center">Salario</th>
                            <th className="text-center">Acciones</th>
                        </tr>
                    </thead>
                    <tbody>

                        {
                            data.length ? 
                                data.slice(0,23).map( (plaza, i) => {
                                    return (
                                        <tr key={plaza.id}>
                                            <td className="text-center">{ plaza.nombre }</td>
                                            <td className="text-center">{ plaza.description }</td>
                                            <td className="text-center">{ plaza.salario }</td>
                                            <td className="actions_butons_plaza"> { actions } </td>
                                        </tr>
                                    )
                                }) : undefined
                        }

                    </tbody>
                    <tfoot>
                        <tr>
                            <th>Nombre de la plaza</th>
                            <th>Descripción</th>
                            <th>Salario</th>
                            <th>Acciones</th>
                        </tr>
                    </tfoot>
                </Table>
            </div>
        </Col>
    )
}


function GridMode () {

    let buttons = [
        <div className="botones_interactivos">
            <span tooltip-location="top" tooltip="Ver plaza">
                <RemoveRedEyeIcon className="grid_btn"/>
            </span>
        </div>,
        <div className="botones_interactivos">
            <span tooltip-location="top" tooltip="Editar plaza">
                <EditIcon className="grid_btn"/>
            </span>
        </div>,
        <div className="botones_interactivos">
            <span tooltip-location="top" tooltip="Eliminar plaza">
                <HighlightOffIcon className="grid_btn"/>
            </span>
        </div>
    ]

    return(
        <React.Fragment> 
            {
                data.length ? 
                data.slice(23).map( plaza => {
                    return(
                        <Col key={plaza.id} lg="4" md="6" sm="6" xs="12" >
                            <div className="panel">
                                <Row>
                                    <Col md="4">
                                        <div className="img-container">
                                            <img alt="not found" src={NotFound}/>
                                        </div>
                                    </Col>
                                    <Col md="8">
                                        <div className="info_details">
                                            <p>{ plaza.nombre }</p>
                                            <p>{ plaza.description }</p>
                                            <p>{ plaza.salario }</p>
                                        </div>
                                        <div className="btn_interactivos">
                                            { buttons }
                                        </div>
                                    </Col>
                                </Row>
                            </div>
                        </Col>
                    )
                }) : undefined
            }
        </React.Fragment>
    )
}

function Manual ( props ) {

    let [ filename, setFilename ] = React.useState(null);

    let { visible, onClose } = props

    // Create a reference to the hidden file input element
    const hiddenFileInput = React.useRef(null);

    // Programatically click the hidden file input element
    // when the Button component is clicked
    const handleClick = event => {
        hiddenFileInput.current.click();
    };
    // Call a function (passed as a prop from the parent component)
    // to handle the user-selected file 
    const handleChange = event => {
        const fileUploaded = event.target.files[0];
        // console.log( "FILE >> ", fileUploaded )
        setFilename( fileUploaded.name )
        //props.handleFile(fileUploaded);
    };

    const validateEmail = (value) => value === "Edgar";

    return (
        <Modal size="lg" aria-labelledby="contained-modal-title-vcenter" centered  show={visible} onHide={onClose}>
            <Modal.Header>
                <button onClick={onClose}  type="button" className="close" data-dismiss="modal">&times;</button>
                <h4 className="modal-title">Agregar plaza</h4>
            </Modal.Header>
            <Modal.Body className="modal-body">

                <Formik
                    initialValues={{
                        nombre: '',
                        description: '',
                        salario: '',
                    }}
                    validationSchema={NewPlazaSchema}
                    onSubmit={async (values) => {
                        console.log('VALUES >> ',values)
                    }} >


                    { ({  errors, touched, validateField, validateForm }) => (
                        <Form>
                            <Row>

                                <Col md="4">
                                    <div className="img-container">
                                        <img alt="agregar plaza manual" src={NotFound}/>
                                    </div>
                                </Col>

                                <Col md="8">

                                    <input 
                                        value={ filename ? filename : "" } 
                                        type="text" 
                                        className="file-upload-input" 
                                        disabled="" 
                                        placeholder="Ningún archivo seleccionado"/>

                                    <Button className="btn_add_producto_confirm" style={{ marginLeft : 15 }} onClick={handleClick}>
                                        SUBIR FOTO
                                    </Button>

                                    <input
                                        type="file"
                                        ref={hiddenFileInput}
                                        onChange={handleChange}
                                        style={{display: 'none'}}
                                    />

                                </Col>

                            </Row>
                            <div className="data_product">
                                <Row>
                                    <Col md="12">

                                        {errors.nombre && touched.nombre && <div className="error_feedback">{errors.nombre}</div>}
                                        <Field name="nombre" placeholder="Nombre de la plaza" validate={validateEmail}/>

                                        {errors.description && touched.description && <div className="error_feedback">{errors.description}</div>}
                                        <Field name="description">
                                            {({ field, form, meta }) => {
                                                return(
                                                    <textarea id="description" name="description" defaultValue="" value={field.value} onChange={field.onChange} placeholder="Descripción general de la plaza"></textarea>
                                                )
                                            }}
                                        </Field>

                                        {errors.salario && touched.salario && <div className="error_feedback">{errors.salario}</div>}
                                        <Field name="salario" type="number" name="salario" placeholder="Salario"/>


                                    </Col>
                                    <div className="add_producto_confirm">
                                        <button className="btn_add_producto_confirm" type="submit">Agregar plaza</button>
                                    </div>
                                </Row>
                            </div>
                        </Form>
                    )}




                </Formik>
            </Modal.Body>
        </Modal>
    )
}

function Express (props) {
    let { visible, onClose } = props
    return (
        <Modal size="lg" aria-labelledby="contained-modal-title-vcenter" centered  show={visible} onHide={onClose}>
            <Modal.Header>
                <button onClick={onClose} type="button" className="close" data-dismiss="modal">&times;</button>
                <h4 className="modal-title">Agregar plaza express</h4>
            </Modal.Header>
            <Modal.Body>
                <div className="data_product">
                    <div className="row">
                        <div className="col-md-12">
                            <input type="link" name="link" placeholder="Link de la plaza"/>
                        </div>
                        <div className="add_producto_confirm">
                            <div className="btn_add_producto_confirm">
                                <span type="submit">Agregar plaza</span>
                            </div>
                        </div>
                    </div>
                </div>
            </Modal.Body>
        </Modal>
    )
}


export function Puestos() {

    const [alignment, setAlignment] = React.useState('list');

    const handleChange = (event, newAlignment) => setAlignment(newAlignment);

    const children = [
        <ToggleButton value="list" key="list">
            <ViewListIcon />
        </ToggleButton>,
        <ToggleButton value="grid" key="grid">
            <ViewModuleIcon/>
        </ToggleButton>,
    ];

    const control = {
        value: alignment,
        onChange: handleChange,
        exclusive: true,
    };


    let [manual, setManual] = React.useState(false);
    let [expres, setExpress] = React.useState(false);

    const showExpress = () => setExpress(true)

    return (
        <div className="content-section">
            <div className="main">
                <Row>
                    <Col md="2" sm="2" xs="2">
                        <div className="breadcrumb-header">
                            <Box sx={{ float : 'left',display: 'flex', flexDirection: 'column', alignItems: 'center', '& > :not(style) + :not(style)': { mt: 2 }, }} >
                                <ToggleButtonGroup size="small" {...control}>
                                    {children}
                                </ToggleButtonGroup>
                            </Box>
                        </div>
                    </Col>
                    <Col md="10" sm='10' xs="10">
                        <div className="add_producto">
                            <div onClick={() => setManual(true) } className="btn_add_producto"> <span >Agregar manual</span> </div>
                        </div>
                        <div onClick={showExpress} className="add_producto">
                            <div className="btn_add_producto"> <span >Agregar express</span> </div>
                        </div>
                    </Col>
                </Row>
                <div className={`main_productos ${ alignment === 'grid' ? 'activar_vista' : 'desactivar_vista'  }`} id="grid_view">
                    <Row>
                        <GridMode/>
                    </Row>
                </div>
                <div className={`main_list_products ${alignment === 'list' ?  'activar_vista' : 'desactivar_vista'}`} id="list_view_products">
                    <Row>
                        <ListMode/>
                    </Row>
                </div>
            </div>
            <Express visible={expres} onClose={ () => setExpress(false) } />
            <Manual visible={manual}  onClose={ () => setManual(false) } />
        </div>
    )
}
